@@ -3,7 +3,8 @@ from django.db import models
 from django.utils.translation import get_language
 from django.utils.translation import ugettext_lazy as _
 
-from simple_translation.utils import get_translation_queryset
+from cms.models import CMSPlugin
+from simple_translation.utils import get_preferred_translation_from_lang
 
 
 class Category(models.Model):
@@ -29,8 +30,11 @@ class Category(models.Model):
         return ('blog_archive_category', (), {'category': self.slug, })
 
     def get_title(self):
+        return self.get_translation().title
+
+    def get_translation(self):
         lang = get_language()
-        return get_translation_queryset(self).filter(language=lang)[0].title
+        return get_preferred_translation_from_lang(self, lang)
 
 
 class CategoryTitle(models.Model):
@@ -49,8 +53,22 @@ class EntryCategory(models.Model):
     entry = models.ForeignKey(
         'cmsplugin_blog.Entry',
         related_name='categories',
+        verbose_name=_('Entry'),
+    )
+
+    category = models.ForeignKey(
+        Category,
+        related_name='entry_categories',
+        verbose_name=_('Category'),
     )
-    category = models.ForeignKey(Category)
 
     class Meta:
         unique_together = ('entry', 'category', )
+
+
+class CategoryPlugin(CMSPlugin):
+    """Plugin, which renders entries belonging to one category."""
+    category = models.ForeignKey(
+        Category,
+        verbose_name=_('Category'),
+    )
