@@ -1,4 +1,4 @@
-"""Templatetafs for the ``cmsplugin_blog_categories`` app."""
+"""Templatetags for the ``cmsplugin_blog_categories`` app."""
 from django import template
 from django.db.models import Count
 
@@ -9,8 +9,13 @@ register = template.Library()
 
 
 @register.assignment_tag
-def get_category(entry):
-    return EntryCategory.objects.get(entry=entry).category
+def get_category(entry=None):
+    if entry:
+        try:
+            return EntryCategory.objects.get(entry=entry).category
+        except EntryCategory.DoesNotExist:
+            pass
+    return None
 
 
 @register.inclusion_tag(
@@ -18,7 +23,7 @@ def get_category(entry):
     takes_context=True)
 def render_category_links(context, exclude_empty=False):
     """Renders a list of all categories in the database."""
-    qs = Category.objects.annotate(num_posts=Count('entrycategory'))
+    qs = Category.objects.annotate(num_posts=Count('entry_categories'))
     if exclude_empty:
         qs = qs.exclude(num_posts=0)
     context.update({'categories': qs, })
